==> qtjambi-printsupport-5.15.12-sources.jar: io/qt/printsupport/QPageSetupDialog.java <==
package io.qt.printsupport;


/**
 * <p>Configuration dialog for the page-related options on a printer</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qpagesetupdialog.html">QPageSetupDialog</a></p>
 */
public class QPageSetupDialog extends io.qt.widgets.QDialog
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QPageSetupDialog.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QPageSetupDialog(io.qt.printsupport.QPrinter, io.qt.widgets.QWidget)}
     *  with <code>parent = null</code>.</p>
     */
    public QPageSetupDialog(io.qt.printsupport.QPrinter printer) {
        this(printer, (io.qt.widgets.QWidget)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qpagesetupdialog.html#QPageSetupDialog">QPageSetupDialog::QPageSetupDialog(QPrinter*,QWidget*)</a></p>
     */
    public QPageSetupDialog(io.qt.printsupport.QPrinter printer, io.qt.widgets.QWidget parent){
        super((QPrivateConstructor)null);
        initialize_native(this, printer, parent);
    }
    
    private native static void initialize_native(QPageSetupDialog instance, io.qt.printsupport.QPrinter printer, io.qt.widgets.QWidget parent);
    
    /**
     * <p>Overloaded constructor for {@link #QPageSetupDialog(io.qt.widgets.QWidget)}
     *  with <code>parent = null</code>.</p>
     */
    public QPageSetupDialog() {
        this((io.qt.widgets.QWidget)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qpagesetupdialog.html#QPageSetupDialog-1">QPageSetupDialog::QPageSetupDialog(QWidget*)</a></p>
     */
    public QPageSetupDialog(io.qt.widgets.QWidget parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QPageSetupDialog instance, io.qt.widgets.QWidget parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qpagesetupdialog.html#printer">QPageSetupDialog::printer()</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.printsupport.QPrinter printer(){
        return printer_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.printsupport.QPrinter printer_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdialog.html#done">QDialog::done(int)</a></p>
     */
    @io.qt.QtUninvokable
    public void done(int result){
        done_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), result);
    }
    
    @io.qt.QtUninvokable
    private native void done_native_int(long __this__nativeId, int result);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdialog.html#exec">QDialog::exec()</a></p>
     */
    @io.qt.QtUninvokable
    public int exec(){
        return exec_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int exec_native(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QPageSetupDialog(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QPageSetupDialog(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QPageSetupDialog instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-printsupport-5.15.16-sources.jar: io/qt/printsupport/QPageSetupDialog.java <==
package io.qt.printsupport;

import io.qt.*;


/**
 * <p>Configuration dialog for the page-related options on a printer</p>
 * <p>Java wrapper for Qt class <code><a href="http://doc.qt.io/qt-5/qpagesetupdialog.html">QPageSetupDialog</a></code></p>
 */
public class QPageSetupDialog extends io.qt.widgets.QDialog
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QPageSetupDialog.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QPageSetupDialog(io.qt.printsupport.QPrinter, io.qt.widgets.QWidget)}
     *  with <code>parent = null</code>.</p>
     */
    public QPageSetupDialog(io.qt.printsupport.@Nullable QPrinter printer) {
        this(printer, (io.qt.widgets.QWidget)null);
    }
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qpagesetupdialog.html#QPageSetupDialog">QPageSetupDialog::<wbr>QPageSetupDialog(QPrinter*,<wbr>QWidget*)</a></code></p>
     */
    public QPageSetupDialog(io.qt.printsupport.@Nullable QPrinter printer, io.qt.widgets.@Nullable QWidget parent){
        super((QPrivateConstructor)null);
        initialize_native(this, printer, parent);
    }
    
    private native static void initialize_native(QPageSetupDialog instance, io.qt.printsupport.QPrinter printer, io.qt.widgets.QWidget parent);
    
    /**
     * <p>Overloaded constructor for {@link #QPageSetupDialog(io.qt.widgets.QWidget)}
     *  with <code>parent = null</code>.</p>
     */
    public QPageSetupDialog() {
        this((io.qt.widgets.QWidget)null);
    }
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qpagesetupdialog.html#QPageSetupDialog-1">QPageSetupDialog::<wbr>QPageSetupDialog(QWidget*)</a></code></p>
     */
    public QPageSetupDialog(io.qt.widgets.@Nullable QWidget parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QPageSetupDialog instance, io.qt.widgets.QWidget parent);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qpagesetupdialog.html#printer">QPageSetupDialog::<wbr>printer()</a></code></p>
     */
    @QtUninvokable
    public final io.qt.printsupport.@Nullable QPrinter printer(){
        return printer_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.printsupport.QPrinter printer_native(long __this__nativeId);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qdialog.html#done">QDialog::<wbr>done(int)</a></code></p>
     */
    @QtUninvokable
    public void done(int result){
        done_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), result);
    }
    
    @QtUninvokable
    private native void done_native_int(long __this__nativeId, int result);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qdialog.html#exec">QDialog::<wbr>exec()</a></code></p>
     */
    @QtUninvokable
    public int exec(){
        return exec_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int exec_native(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QPageSetupDialog(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * @hidden
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QPageSetupDialog(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QPageSetupDialog instance, QDeclarativeConstructor constructor);
    
}
